==> crunchyfrog-0.3.1.tar.gz: crunchyfrog-0.3.1/cf/release.py <==
# -*- coding: utf-8 -*-

# crunchyfrog - a database schema browser and query tool
# Copyright (C) 2008 Andi Albrecht <albrecht.andi@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# $Id$

"""Release information"""

name = "CrunchyFrog"
appname = name.lower()
version = "0.3.1"
copyright = "Copyright (C) 2008 Andi Albrecht <albrecht.andi@gmail.com>"
description = "Database front-end for GNOME"
author = "Andi Albrecht"
author_email = "albrecht.andi@gmail.com"
url = "http://crunchyfrog.googlecode.com"
long_description = """CrunchyFrog is a database front-end for the GNOME desktop.

Supported databases
===================

 * PostgreSQL (requires psycopg2)
 * MySQL (requires MySQLdb)
 * SQLite3 (requires python-sqlite3)
 * Oracle (requires cx_Oracle)
 * MS-SQL Server (requires pymssql)
 * LDAP (requires python-ldap)

It is written in Python (PyGTK) and can be extended using plugins.

Check out the homepage for the most recent version and details."""

license = """This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>."""

translators="""Kari Argillander (https://launchpad.net/~kari-argillander)
cd (https://launchpad.net/~zadoev)
Thanos Chatziathanassiou (https://launchpad.net/~tchatzi)
Edwin Dijk (https://launchpad.net/~sitix)
Micke Elm (https://launchpad.net/~mickeelm)
Anthony Guéchoum (https://launchpad.net/~athael)
Guybrush88 (https://launchpad.net/~erpizzo)
Ryutatsu Ishigami (https://launchpad.net/~ai-inside+ubuntu)
Luca Livraghi (https://launchpad.net/~luca91)
Marion Cisternas Milla (https://launchpad.net/~mcisternas)
Christian Olate Opazo (https://launchpad.net/~cristian-olate)
Penegal (https://launchpad.net/~penegal)
Martin Picek <picek.martin@gnome-cesko.cz>
Nicola Piovesan (https://launchpad.net/~piovesannicola)
rcares (https://launchpad.net/~rcares)
Enrico Rosina (https://launchpad.net/~e-rosina)
Xoan Sampaiño (https://launchpad.net/~xoan)
Skiros (https://launchpad.net/~magoskiros)
Pierre Slamich (https://launchpad.net/~pierre-slamich)
Jeppe Toustrup (https://launchpad.net/~tenzer)
ubby (https://launchpad.net/~kostas-sytske)
Linus C Unneback (https://launchpad.net/~linus-folkdatorn)
Yaron (https://launchpad.net/~sh-yaron)
Muhammad Zulfikar (https://launchpad.net/~zulfikars)
0x00080h (https://launchpad.net/~einstein89)
"""

==> crunchyfrog_0.4.1.orig.tar.gz: crunchyfrog-0.4.1/cf/release.py <==
# -*- coding: utf-8 -*-

# crunchyfrog - a database schema browser and query tool
# Copyright (C) 2008 Andi Albrecht <albrecht.andi@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Release information"""

name = "CrunchyFrog"
appname = name.lower()
version = "0.4.1"
copyright = "Copyright (C) 2009 Andi Albrecht <albrecht.andi@gmail.com>"
description = "SQL client (not-only) for GNOME"
author = "Andi Albrecht"
author_email = "albrecht.andi@gmail.com"
url = "http://crunchyfrog.googlecode.com"
long_description = """CrunchyFrog is a database navigator and SQL client.

It's mainly written for GNOME but it should run in other environments too.

Supported databases
===================

 * PostgreSQL
 * MySQL
 * SQLite3
 * Oracle
 * SQL Server
 * Firebird
 * Informix
 * MaxDB

It is written in Python (PyGTK) and can be extended using plugins.

Check out the homepage for the most recent version and details."""

license = """This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>."""

translators="""Thanks to all Launchpad contributors!
Alexandr Udovichenko (https://translations.launchpad.net/~gragdanin)
Anthony Guéchoum (https://launchpad.net/~athael)
cd (https://launchpad.net/~zadoev)
Christophe Chauvet (https://launchpad.net/~christophe-chauvet)
Christian Olate Opazo (https://launchpad.net/~cristian-olate)
Daniel Nylander (https://translations.launchpad.net/~yeager)
Dante Díaz (https://launchpad.net/~dante)
David A Páez (https://launchpad.net/~orlsend)
DiegoJ (https://launchpad.net/~diegojromerolopez)
dvdmeer (https://translations.launchpad.net/~dennis-dvdmeer)
Edwin Dijk (https://launchpad.net/~sitix)
Enrico Rosina (https://launchpad.net/~e-rosina)
Feder Sáiz (https://launchpad.net/~federsaiz)
Guybrush88 (https://launchpad.net/~erpizzo)
Jen Ockwell (https://launchpad.net/~rj-ockwell)
Jeppe Toustrup (https://launchpad.net/~tenzer)
Kari Argillander (https://launchpad.net/~kari-argillander)
kezar (https://launchpad.net/~kezar)
Linus C Unneback (https://launchpad.net/~linus-folkdatorn)
Luca Livraghi (https://launchpad.net/~luca91)
Marion Cisternas Milla (https://launchpad.net/~mcisternas)
Martin Picek <picek.martin@gnome-cesko.cz>
Micke Elm (https://launchpad.net/~mickeelm)
Muhammad Zulfikar (https://launchpad.net/~zulfikars)
Nicola Piovesan (https://launchpad.net/~piovesannicola)
Penegal (https://launchpad.net/~penegal)
Pierre Slamich (https://launchpad.net/~pierre-slamich)
rcares (https://launchpad.net/~rcares)
Ryutatsu Ishigami (https://launchpad.net/~ai-inside+ubuntu)
Skiros (https://launchpad.net/~magoskiros)
Thanos Chatziathanassiou (https://launchpad.net/~tchatzi)
TRanslate (https://launchpad.net/~translatematic)
ubby (https://launchpad.net/~kostas-sytske)
Vadim Peretokin (https://launchpad.net/~vperetokin)
Xoan Sampaiño (https://launchpad.net/~xoan)
Yaron (https://launchpad.net/~sh-yaron)
0x00080h (https://launchpad.net/~einstein89)
"""
